/**
 * EasyBeans
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: SingletonBean.java 5369 2010-02-24 14:58:19Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.examples.singleton;

import javax.annotation.PostConstruct;
import javax.ejb.EJB;

/**
 * Defines a singleton that is initialized at an undefined time (lazy loading).
 * @author Florent Benoit
 */
@javax.ejb.Singleton(mappedName = "SingletonBean1")
public class SingletonBean extends AbsSingleton {

    /**
     * Link to the eager singleton.
     */
    @EJB(beanName = "EagerSingletonBean")
    private ISingletonShared eagerSingleton;

    /**
     * @return shared value.
     */
    @Override
    public int getShared() {
        return this.eagerSingleton.getShared();
    }

    /**
     * Initialize the singleton.
     */
    @PostConstruct
    public void init() {
        System.out.println(this.getClass().getName() + ": Init !");
    }

}
